package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcDeviceScrapMapper;
import com.ruoyi.oa.domain.CmcDeviceScrap;
import com.ruoyi.oa.service.ICmcDeviceScrapService;

/**
 * cmc设备报废Service业务层处理
 * 
 * @author cmc
 * @date 2024-05-21
 */
@Service
public class CmcDeviceScrapServiceImpl implements ICmcDeviceScrapService 
{
    @Autowired
    private CmcDeviceScrapMapper cmcDeviceScrapMapper;

    /**
     * 查询cmc设备报废
     * 
     * @param deviceScrapId cmc设备报废主键
     * @return cmc设备报废
     */
    @Override
    public CmcDeviceScrap selectCmcDeviceScrapByDeviceScrapId(Integer deviceScrapId)
    {
        return cmcDeviceScrapMapper.selectCmcDeviceScrapByDeviceScrapId(deviceScrapId);
    }

    /**
     * 查询cmc设备报废列表
     * 
     * @param cmcDeviceScrap cmc设备报废
     * @return cmc设备报废
     */
    @Override
    public List<CmcDeviceScrap> selectCmcDeviceScrapList(CmcDeviceScrap cmcDeviceScrap)
    {
        return cmcDeviceScrapMapper.selectCmcDeviceScrapList(cmcDeviceScrap);
    }

    /**
     * 新增cmc设备报废
     * 
     * @param cmcDeviceScrap cmc设备报废
     * @return 结果
     */
    @Override
    public int insertCmcDeviceScrap(CmcDeviceScrap cmcDeviceScrap)
    {
        return cmcDeviceScrapMapper.insertCmcDeviceScrap(cmcDeviceScrap);
    }

    /**
     * 修改cmc设备报废
     * 
     * @param cmcDeviceScrap cmc设备报废
     * @return 结果
     */
    @Override
    public int updateCmcDeviceScrap(CmcDeviceScrap cmcDeviceScrap)
    {
        return cmcDeviceScrapMapper.updateCmcDeviceScrap(cmcDeviceScrap);
    }

    /**
     * 批量删除cmc设备报废
     * 
     * @param deviceScrapIds 需要删除的cmc设备报废主键
     * @return 结果
     */
    @Override
    public int deleteCmcDeviceScrapByDeviceScrapIds(Integer[] deviceScrapIds)
    {
        return cmcDeviceScrapMapper.deleteCmcDeviceScrapByDeviceScrapIds(deviceScrapIds);
    }

    /**
     * 删除cmc设备报废信息
     * 
     * @param deviceScrapId cmc设备报废主键
     * @return 结果
     */
    @Override
    public int deleteCmcDeviceScrapByDeviceScrapId(Integer deviceScrapId)
    {
        return cmcDeviceScrapMapper.deleteCmcDeviceScrapByDeviceScrapId(deviceScrapId);
    }
}
